import { parseArgs } from "node:util";
import * as prompts from "@clack/prompts";
import chalk from "chalk";
import { titleCase } from "title-case";
import { logLine } from "./cli/lines.js";
import { getDefaultSettings } from "./defaults.js";
import { ensureRepositoryExists } from "./ensureRepositoryExists.js";
import { getOctokit } from "./getOctokit.js";
import { optionalDefault } from "./optionalDefault.js";
import { handlePromptCancel } from "./prompts.js";
export async function getInputValuesAndOctokit(args, defaults = {}) {
    let shouldLogLineBeforePrefill = true;
    const { defaultOwner, defaultRepository } = await getDefaultSettings();
    const { values } = parseArgs({
        args,
        options: {
            author: { type: "string" },
            description: { type: "string" },
            email: { type: "string" },
            funding: { type: "string" },
            owner: { type: "string" },
            releases: { type: "boolean" },
            repository: { type: "string" },
            unitTests: { type: "boolean" },
            title: { type: "string" },
            "skip-api": { type: "boolean" },
            "skip-removal": { type: "boolean" },
            "skip-restore": { type: "boolean" },
            "skip-uninstall": { type: "boolean" },
        },
        tokens: true,
        strict: false,
    });
    const owner = await getPrefillOrPromptedValue("owner", "What owner or user will the repository be under?", defaultOwner);
    const octokit = await getOctokit(!!values["skip-api"]);
    shouldLogLineBeforePrefill = true;
    const repository = await ensureRepositoryExists(octokit, owner, await getPrefillOrPromptedValue("repository", "What will the kebab-case name of the repository be?", defaultRepository));
    const title = await getPrefillOrPromptedValue("title", "What will the Title Case title of the repository be?", titleCase(repository).replaceAll("-", " "));
    const description = await getPrefillOrPromptedValue("description", "How would you describe the new package?", "A very lovely package. Hooray!");
    return {
        octokit,
        values: {
            author: await optionalDefault(values.author, defaults.author),
            email: await optionalDefault(values.email, defaults.email),
            funding: await optionalDefault(values.funding, defaults.funding),
            releases: await optionalDefault(values.releases, defaults.releases),
            unitTests: await optionalDefault(values.unitTests, defaults.unitTests),
            description,
            owner,
            repository,
            skipApi: !!values["skip-api"],
            skipRemoval: !!values["skip-removal"],
            skipRestore: !!values["skip-restore"],
            skipUninstalls: !!values["skip-uninstalls"],
            title,
        },
    };
    async function getPrefillOrPromptedValue(key, message, placeholder) {
        const existing = values[key];
        if (existing) {
            if (shouldLogLineBeforePrefill) {
                logLine();
                shouldLogLineBeforePrefill = false;
            }
            logLine(chalk.gray(`Pre-filling ${key} to ${existing}.`));
            return existing;
        }
        const value = await prompts.text({
            message,
            placeholder,
            validate: (val) => {
                if (val.length === 0) {
                    return "Please enter a value.";
                }
            },
        });
        handlePromptCancel(value);
        return value;
    }
}
//# sourceMappingURL=inputs.js.map